@@ -12,6 +12,8 @@ from .purchaseorder import PurchaseOrder
 from .supplier import Supplier
 from .user import User
 from .warehouse import Warehouse
+from .webhook import Webhook
+
 
 __all__: list[str] = [
     'Order',
@@ -19,5 +21,6 @@ __all__: list[str] = [
     'PurchaseOrder',
     'Supplier',
     'User',
-    'Warehouse'
+    'Warehouse',
+    'Webhook',
 ]
\ No newline at end of file
